@@ -18,18 +18,17 @@ import binascii
 import copy
 import mock
 import six
-import uuid
 
 from castellan.common.objects import symmetric_key as key
 from castellan.tests.unit.key_manager import fake
 from os_brick.encryptors import cryptsetup
 from os_brick import exception
 from os_brick.tests.encryptors import test_base
-from oslo_concurrency import processutils as putils
 
 
-def fake__get_key(context, passphrase):
-    raw = bytes(binascii.unhexlify(passphrase))
+def fake__get_key(context):
+    raw = bytes(binascii.unhexlify('0' * 32))
+
     symmetric_key = key.SymmetricKey('AES', len(raw) * 8, raw)
     return symmetric_key
 
@@ -37,13 +36,13 @@ def fake__get_key(context, passphrase):
 @mock.patch('os_brick.executor.encodeutils.safe_decode',
             lambda x, errors=None: x)
 class CryptsetupEncryptorTestCase(test_base.VolumeEncryptorTestCase):
-
     @mock.patch('os.path.exists', return_value=False)
-    def _create(self, mock_exists):
-        return cryptsetup.CryptsetupEncryptor(
-            connection_info=self.connection_info,
-            root_helper=self.root_helper,
-            keymgr=self.keymgr)
+    def _create(self, mock_exists, root_helper,
+                connection_info, keymgr, execute):
+        return cryptsetup.CryptsetupEncryptor(root_helper=root_helper,
+                                              connection_info=connection_info,
+                                              keymgr=keymgr,
+                                              execute=execute)
 
     def setUp(self):
         super(CryptsetupEncryptorTestCase, self).setUp()
@@ -53,11 +52,10 @@ class CryptsetupEncryptorTestCase(test_base.VolumeEncryptorTestCase):
 
         self.symlink_path = self.dev_path
 
-    @mock.patch('os_brick.executor.Executor._execute')
-    def test__open_volume(self, mock_execute):
+    def test__open_volume(self):
         self.encryptor._open_volume("passphrase")
 
-        mock_execute.assert_has_calls([
+        self.assert_exec_has_calls([
             mock.call('cryptsetup', 'create', '--key-file=-', self.dev_name,
                       self.dev_path, process_input='passphrase',
                       run_as_root=True,
@@ -65,17 +63,15 @@ class CryptsetupEncryptorTestCase(test_base.VolumeEncryptorTestCase):
                       check_exit_code=True),
         ])
 
-    @mock.patch('os_brick.executor.Executor._execute')
-    def test_attach_volume(self, mock_execute):
-        fake_key = uuid.uuid4().hex
+    def test_attach_volume(self):
         self.encryptor._get_key = mock.MagicMock()
-        self.encryptor._get_key.return_value = fake__get_key(None, fake_key)
+        self.encryptor._get_key.return_value = fake__get_key(None)
 
         self.encryptor.attach_volume(None)
 
-        mock_execute.assert_has_calls([
+        self.assert_exec_has_calls([
             mock.call('cryptsetup', 'create', '--key-file=-', self.dev_name,
-                      self.dev_path, process_input=fake_key,
+                      self.dev_path, process_input='0' * 32,
                       root_helper=self.root_helper,
                       run_as_root=True, check_exit_code=True),
             mock.call('ln', '--symbolic', '--force',
@@ -84,21 +80,19 @@ class CryptsetupEncryptorTestCase(test_base.VolumeEncryptorTestCase):
                       run_as_root=True, check_exit_code=True),
         ])
 
-    @mock.patch('os_brick.executor.Executor._execute')
-    def test__close_volume(self, mock_execute):
+    def test__close_volume(self):
         self.encryptor.detach_volume()
 
-        mock_execute.assert_has_calls([
+        self.assert_exec_has_calls([
             mock.call('cryptsetup', 'remove', self.dev_name,
                       root_helper=self.root_helper,
                       run_as_root=True, check_exit_code=True),
         ])
 
-    @mock.patch('os_brick.executor.Executor._execute')
-    def test_detach_volume(self, mock_execute):
+    def test_detach_volume(self):
         self.encryptor.detach_volume()
 
-        mock_execute.assert_has_calls([
+        self.assert_exec_has_calls([
             mock.call('cryptsetup', 'remove', self.dev_name,
                       root_helper=self.root_helper,
                       run_as_root=True, check_exit_code=True),
@@ -117,27 +111,26 @@ class CryptsetupEncryptorTestCase(test_base.VolumeEncryptorTestCase):
                                 keymgr=fake.fake_api())
         self.assertIn(type, six.text_type(exc))
 
-    @mock.patch('os_brick.executor.Executor._execute')
     @mock.patch('os.path.exists', return_value=True)
-    def test_init_volume_encryption_with_old_name(self, mock_exists,
-                                                  mock_execute):
+    def test_init_volume_encryption_with_old_name(self,
+                                                  mock_exists):
         # If an old name crypt device exists, dev_path should be the old name.
         old_dev_name = self.dev_path.split('/')[-1]
         encryptor = cryptsetup.CryptsetupEncryptor(
             root_helper=self.root_helper,
             connection_info=self.connection_info,
-            keymgr=self.keymgr)
+            keymgr=fake.fake_api(),
+            execute=self.mock_execute)
         self.assertFalse(encryptor.dev_name.startswith('crypt-'))
         self.assertEqual(old_dev_name, encryptor.dev_name)
         self.assertEqual(self.dev_path, encryptor.dev_path)
         self.assertEqual(self.symlink_path, encryptor.symlink_path)
         mock_exists.assert_called_once_with('/dev/mapper/%s' % old_dev_name)
-        mock_execute.assert_called_once_with(
+        self.mock_execute.assert_called_once_with(
             'cryptsetup', 'status', old_dev_name, run_as_root=True)
 
-    @mock.patch('os_brick.executor.Executor._execute')
     @mock.patch('os.path.exists', side_effect=[False, True])
-    def test_init_volume_encryption_with_wwn(self, mock_exists, mock_execute):
+    def test_init_volume_encryption_with_wwn(self, mock_exists):
         # If an wwn name crypt device exists, dev_path should be based on wwn.
         old_dev_name = self.dev_path.split('/')[-1]
         wwn = 'fake_wwn'
@@ -147,7 +140,7 @@ class CryptsetupEncryptorTestCase(test_base.VolumeEncryptorTestCase):
             root_helper=self.root_helper,
             connection_info=connection_info,
             keymgr=fake.fake_api(),
-            execute=mock_execute)
+            execute=self.mock_execute)
         self.assertFalse(encryptor.dev_name.startswith('crypt-'))
         self.assertEqual(wwn, encryptor.dev_name)
         self.assertEqual(self.dev_path, encryptor.dev_path)
@@ -155,36 +148,5 @@ class CryptsetupEncryptorTestCase(test_base.VolumeEncryptorTestCase):
         mock_exists.assert_has_calls([
             mock.call('/dev/mapper/%s' % old_dev_name),
             mock.call('/dev/mapper/%s' % wwn)])
-        mock_execute.assert_called_once_with(
+        self.mock_execute.assert_called_once_with(
             'cryptsetup', 'status', wwn, run_as_root=True)
-
-    @mock.patch('os_brick.executor.Executor._execute')
-    def test_attach_volume_unmangle_passphrase(self, mock_execute):
-        fake_key = '0725230b'
-        fake_key_mangled = '72523b'
-        self.encryptor._get_key = mock.MagicMock()
-        self.encryptor._get_key.return_value = fake__get_key(None, fake_key)
-
-        mock_execute.side_effect = [
-            putils.ProcessExecutionError(exit_code=2),  # luksOpen
-            mock.DEFAULT,
-            mock.DEFAULT,
-        ]
-
-        self.encryptor.attach_volume(None)
-
-        mock_execute.assert_has_calls([
-            mock.call('cryptsetup', 'create', '--key-file=-', self.dev_name,
-                      self.dev_path, process_input=fake_key,
-                      root_helper=self.root_helper, run_as_root=True,
-                      check_exit_code=True),
-            mock.call('cryptsetup', 'create', '--key-file=-', self.dev_name,
-                      self.dev_path, process_input=fake_key_mangled,
-                      root_helper=self.root_helper, run_as_root=True,
-                      check_exit_code=True),
-            mock.call('ln', '--symbolic', '--force',
-                      '/dev/mapper/%s' % self.dev_name, self.symlink_path,
-                      root_helper=self.root_helper, run_as_root=True,
-                      check_exit_code=True),
-        ])
-        self.assertEqual(3, mock_execute.call_count)
